@@ -2,7 +2,7 @@ from python_framework.api.src.enumeration.HttpStatus import HttpStatus
 from python_framework.api.src.service.flask.FlaskManager import Controller, ControllerMethod
 from python_framework.api.src.dto import ActuatorHealthDto
 
-@Controller(url='/actuator/health', tag='HealthCheck', description='HealthCheck controller')
+@Controller(url='/health', tag='HealthCheck', description='HealthCheck controller')
 class ActuatorHealthController:
 
     @ControllerMethod(
